=head1 NAME
HISTORY - release history for Data::Dumper
=head1 DESCRIPTION
=over 8
=item 2.00beta (9 April 1996)
C<Dumpxs> is now the exact XSUB equivalent of C<Dump>. The XS version
is 4-5 times faster.
C<require 5.002>.
MLDBM example removed (as its own module, it has a separate CPAN
reality now).
Fixed bugs in handling keys with wierd characters. Perl can be
tripped up in its implicit quoting of the word before '=>'. The
fix: C<Data::Dumper::Purity>, when set, always triggers quotes
around hash keys.
Andreas Koenig <kanna@mind.de> pointed out that handling octals
is busted. His patch added.
Dead code removed, other minor documentation fixes.
=item 1.23 (3 Dec 1995)
MLDBM example added.
Several folks pointed out that quoting of ticks and backslashes
in strings is missing. Added.
Ian Phillips <ian@pipex.net> pointed out that numerics may lose
precision without quotes. Fixed.
=item 1.21 (20 Nov 1995)
Last stable version I can remember.
=back
=cut